@@ -5,16 +5,17 @@ Author:   guido socher <guido(at)linuxfocus.org>
 Copyright: GPL
 **************************************************************************/
 
-#include <io.h>
-#include <progmem.h>
-#include <interrupt.h>
-#include <string-avr.h>
+#include <avr/io.h>
+#include <avr/pgmspace.h>
+#include <avr/interrupt.h>
+#include <string.h>
 #include <stdlib.h>
 #include "lcd.h"	/* these are the prototypes and defines for lcd.c */
 #include "avr-util.h"
 #include "uart.h"
 #include "analog.h"
 #include "hardwarewd.h"
+#include "avr_compat.h"
 
 static char uart_outbuf[UART_RX_BUFFER_SIZE+1];
 
@@ -43,7 +44,7 @@ static char uart_outbuf[UART_RX_BUFFER_SIZE+1];
 #define AWDTOUT 20
 int main(void)
 {
-	char *banner = PSTR ("linuxfocus.org");
+	char *banner = (char *)PSTR("linuxfocus.org");
 	unsigned char i,j,banneron,rxresult,status,buttoninfo,autokickwd;
 	int i16bit;
 	unsigned int ignorebutton;
